==> haskell-pandoc-types-1.16.0.1-4-armv7h.pkg.tar.xz: usr/share/haskell/haskell-pandoc-types/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: pandoc-types
version: 1.16.0.1
id: pandoc-types-1.16.0.1-34128572b9929354379ebf9e0bcb880e
key: pando_JqKw0iRTgUN3jC9rDucqnx
license: BSD3
copyright: (c) 2006-2015 John MacFarlane
maintainer: jgm@berkeley.edu
homepage: http://johnmacfarlane.net/pandoc
synopsis: Types for representing a structured document
description:
    @Text.Pandoc.Definition@ defines the '\''Pandoc'\'' data
    structure, which is used by pandoc to represent
    structured documents.  This module used to live
    in the pandoc package, but starting with pandoc 1.7, it
    has been split off, so that other packages can use it
    without drawing in all of pandoc'\''s dependencies, and
    pandoc itself can depend on packages (like citeproc-hs)
    that use them.
    .
    @Text.Pandoc.Builder@ provides functions for building
    up @Pandoc@ structures programmatically.
    .
    @Text.Pandoc.Generic@ provides generic functions for
    manipulating Pandoc documents.
    .
    @Text.Pandoc.Walk@ provides faster, nongeneric functions
    for manipulating Pandoc documents.
    .
    @Text.Pandoc.JSON@ provides functions for serializing
    and deserializing a @Pandoc@ structure to and from JSON.
category: Text
author: John MacFarlane
exposed: True
exposed-modules:
    Text.Pandoc.Definition Text.Pandoc.Generic Text.Pandoc.Walk
    Text.Pandoc.Builder Text.Pandoc.JSON
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/pandoc-types-1.16.0.1
library-dirs: /usr/lib/ghc-7.10.3/site-local/pandoc-types-1.16.0.1
data-dir: /usr/share/arm-linux-ghc-7.10.3/pandoc-types-1.16.0.1
hs-libraries: HSpandoc-types-1.16.0.1-JqKw0iRTgUN3jC9rDucqnx
depends:
    aeson-0.10.0.0-d37842f030fec47bc6e0ba2aef0f6571
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
    deepseq-1.4.1.1-3975618f889b45239daa47b7443eaeee
    ghc-prim-0.4.0.0-bf246eb9fdda7435f0c147a313ce59fb
    syb-0.6-56a5944f55f7a9d47e7b770375c0e1ae
haddock-interfaces: /usr/share/doc/haskell-pandoc-types/html/pandoc-types.haddock
haddock-html: /usr/share/doc/haskell-pandoc-types/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"

==> haskell-pandoc-types-1.16.1-7-armv7h.pkg.tar.xz: usr/share/haskell/haskell-pandoc-types/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: pandoc-types
version: 1.16.1
id: pandoc-types-1.16.1-4cd1533070797f7596c108f3982c26c4
key: pando_454MtrvEViEEUr9vMtnYwm
license: BSD3
copyright: (c) 2006-2015 John MacFarlane
maintainer: jgm@berkeley.edu
homepage: http://johnmacfarlane.net/pandoc
synopsis: Types for representing a structured document
description:
    @Text.Pandoc.Definition@ defines the '\''Pandoc'\'' data
    structure, which is used by pandoc to represent
    structured documents.  This module used to live
    in the pandoc package, but starting with pandoc 1.7, it
    has been split off, so that other packages can use it
    without drawing in all of pandoc'\''s dependencies, and
    pandoc itself can depend on packages (like citeproc-hs)
    that use them.
    .
    @Text.Pandoc.Builder@ provides functions for building
    up @Pandoc@ structures programmatically.
    .
    @Text.Pandoc.Generic@ provides generic functions for
    manipulating Pandoc documents.
    .
    @Text.Pandoc.Walk@ provides faster, nongeneric functions
    for manipulating Pandoc documents.
    .
    @Text.Pandoc.JSON@ provides functions for serializing
    and deserializing a @Pandoc@ structure to and from JSON.
category: Text
author: John MacFarlane
exposed: True
exposed-modules:
    Text.Pandoc.Definition Text.Pandoc.Generic Text.Pandoc.Walk
    Text.Pandoc.Builder Text.Pandoc.JSON
hidden-modules: Paths_pandoc_types
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/pandoc-types-1.16.1
library-dirs: /usr/lib/ghc-7.10.3/site-local/pandoc-types-1.16.1
data-dir: /usr/share/arm-linux-ghc-7.10.3/pandoc-types-1.16.1
hs-libraries: HSpandoc-types-1.16.1-454MtrvEViEEUr9vMtnYwm
depends:
    aeson-0.11.1.1-0413068b3d94ca1008e286bfe7fa084f
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
    deepseq-1.4.1.1-3975618f889b45239daa47b7443eaeee
    ghc-prim-0.4.0.0-bf246eb9fdda7435f0c147a313ce59fb
    syb-0.6-56a5944f55f7a9d47e7b770375c0e1ae
haddock-interfaces: /usr/share/doc/haskell-pandoc-types/html/pandoc-types.haddock
haddock-html: /usr/share/doc/haskell-pandoc-types/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
